@@ -55,7 +55,7 @@ OC.L10N.register(
     "Actions" : "Acciones",
     "General" : "General",
     "Editing" : "Editando",
-    "Keyboard shortcuts" : "Atajos de teclado",
+    "Files" : "Archivo",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
