@@ -137,7 +137,6 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipo)",
     "An error occurred while unsharing the calendar." : "Ocurrió un error al dejar de compartir el calendario.",
     "An error occurred, unable to change the permission of the share." : "Ocurrió un error, no se pudieron cambiar los permisos del recurso compartido.",
-    "can edit" : "puede editar",
     "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "Sin usuarios ni grupos",
@@ -158,7 +157,6 @@ OC.L10N.register(
     "Invalid location selected" : "Ubicación seleccionada inválida",
     "Attachments folder successfully saved." : "La carpeta de adjuntos se guardó exitosamente.",
     "Error on saving attachments folder." : "Ocurrió un error al guardar la carpeta de adjuntos.",
-    "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "{filename} could not be parsed" : "No se pudo analizar {filename}",
     "No valid files found, aborting import" : "No se encontraron archivos válidos, cancelando la importación",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se importó exitosamente %n evento","Se importaron exitosamente %n eventos","Se importaron exitosamente %n eventos"],
@@ -189,20 +187,11 @@ OC.L10N.register(
     "At event start" : "Al comienzo del evento",
     "No reminder" : "Sin recordatorio",
     "Failed to save default calendar" : "No se pudo guardar el calendario predeterminado",
-    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
-    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
     "General" : "General",
-    "Personal availability settings" : "Configuración de disponibilidad personal",
-    "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
-    "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
-    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
-    "Show tasks in calendar" : "Mostrar tareas en el calendario",
-    "Show weekends" : "Mostrar fines de semana",
-    "Show week numbers" : "Mostrar número de semana",
+    "Appearance" : "Apariencia",
     "Editing" : "Editando",
-    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
     "Default reminder" : "Recordatorio predeterminado",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Files" : "Archivo",
     "Appointment schedule successfully created" : "El cronograma de citas fue creado exitosamente",
     "Appointment schedule successfully updated" : "El cronograma de citas fue actualizado exitosamente",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
@@ -329,12 +318,7 @@ OC.L10N.register(
     "Decline" : "Rechazar",
     "Tentative" : "Tentativo",
     "No attendees yet" : "Aún no hay asistentes",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitados, {confirmedCount} confirmados",
-    "Successfully appended link to talk room to location." : "Se ha añadido correctamente el enlace a la sala de conversación a la ubicación.",
-    "Successfully appended link to talk room to description." : "Se ha añadido correctamente el enlace a la sala de conversación a la descripción.",
-    "Error creating Talk room" : "Error al crear la sala de Talk",
     "Attendees" : "Asistentes",
-    "_%n more guest_::_%n more guests_" : ["%n invitado más","%n más invitados","%n más invitados"],
     "Remove group" : "Eliminar grupo",
     "Remove attendee" : "Eliminar asistente",
     "Request reply" : "Solicitar respuesta",
@@ -528,7 +512,6 @@ OC.L10N.register(
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
     "Add a location" : "Añadir ubicación",
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
@@ -553,12 +536,30 @@ OC.L10N.register(
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
     "Hidden" : "Oculto",
+    "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
+    "Default attachments location" : "Ubicación predeterminada para adjuntos",
     "Automatic ({detected})" : "Automático ({detected})",
     "Shortcut overview" : "Vista general de atajos",
+    "CalDAV link copied to clipboard." : "Enlace CalDAV copiado al portapapeles.",
+    "CalDAV link could not be copied to clipboard." : "No se pudo copiar el enlace CalDAV al portapapeles.",
+    "Enable birthday calendar" : "Habilitar el calendario de cumpleaños",
+    "Show tasks in calendar" : "Mostrar tareas en el calendario",
     "Enable simplified editor" : "Habilitar el editor simplificado",
     "Limit the number of events displayed in the monthly view" : "Limitar el número de eventos mostrados en la vista mensual",
+    "Show weekends" : "Mostrar fines de semana",
+    "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
-    "Show keyboard shortcuts" : "Mostrar atajos de teclado"
+    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
+    "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
+    "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
+    "Personal availability settings" : "Configuración de disponibilidad personal",
+    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitados, {confirmedCount} confirmados",
+    "Successfully appended link to talk room to location." : "Se ha añadido correctamente el enlace a la sala de conversación a la ubicación.",
+    "Successfully appended link to talk room to description." : "Se ha añadido correctamente el enlace a la sala de conversación a la descripción.",
+    "Error creating Talk room" : "Error al crear la sala de Talk",
+    "_%n more guest_::_%n more guests_" : ["%n invitado más","%n más invitados","%n más invitados"],
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
