@@ -108,7 +108,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
     "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
     "Deck" : "Longgok",
-    "Hidden" : "Sembunyi",
     "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
     "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
     "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
@@ -126,7 +125,6 @@ OC.L10N.register(
     "Deleting share link …" : "Menghapus tautan berbagi …",
     "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
-    "can edit" : "dapat edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
@@ -139,6 +137,7 @@ OC.L10N.register(
     "Invalid location selected" : "Lokasi yang tidak valid dipilih",
     "Attachments folder successfully saved." : "Folder lampiran berhasil disimpan.",
     "Error on saving attachments folder." : "Kesalahan saat menyimpan folder lampiran.",
+    "Attachments folder" : "Folder lampiran",
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
@@ -156,17 +155,9 @@ OC.L10N.register(
     "Create event" : "Buat acara",
     "Show shortcuts" : "Tampilkan pintasan",
     "or" : "atau",
-    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
-    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
     "General" : "Umum",
-    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
-    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
-    "Show weekends" : "Tampilkan akhir pekan",
-    "Show week numbers" : "Tampilkan nomor pekan",
+    "Appearance" : "Tampilan",
     "Editing" : "Pengeditan",
-    "Keyboard shortcuts" : "Pintasan keyboard",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
@@ -222,8 +213,6 @@ OC.L10N.register(
     "Decline" : "Tolak",
     "Tentative" : "Tentatif",
     "No attendees yet" : "Belum ada peserta",
-    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
-    "Error creating Talk room" : "Galat membuat ruangan Talk",
     "Attendees" : "Peserta",
     "Remove group" : "Hapus grup",
     "Remove attendee" : "Hapus peserta",
@@ -259,6 +248,7 @@ OC.L10N.register(
     "Resources" : "Sumber daya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
+    "None" : "Tidak ada",
     "Create" : "Buat",
     "on {formattedDate}" : "dalam {formattedDate}",
     "Please enter a valid date" : "Silakan isi tanggal valid",
@@ -329,7 +319,6 @@ OC.L10N.register(
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Other" : "Lainnya",
-    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
     "Add a location" : "Tambah lokasi",
     "Status" : "Status",
     "Confirmed" : "Terkonfirmasi",
@@ -344,9 +333,22 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "This is an event reminder." : "Ini adalah pengingat acara.",
+    "Hidden" : "Sembunyi",
+    "can edit" : "dapat edit",
     "Automatic ({detected})" : "Otomatis ({detected})",
     "Shortcut overview" : "Ikhtisar pintasan",
+    "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
+    "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
+    "Enable birthday calendar" : "Aktifkan kalender ulang tahun",
+    "Show tasks in calendar" : "Tampilkan tugas dalam kalender",
     "Enable simplified editor" : "Aktifkan editor serderhana",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci"
+    "Show weekends" : "Tampilkan akhir pekan",
+    "Show week numbers" : "Tampilkan nomor pekan",
+    "Copy primary CalDAV address" : "Salin alamat utama CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Salin alamat CalDAV iOS/macOS",
+    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
+    "Error creating Talk room" : "Galat membuat ruangan Talk",
+    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan."
 },
 "nplurals=1; plural=0;");
