@@ -209,14 +209,11 @@ OC.L10N.register(
     "At event start" : "На почетокот на настанот",
     "No reminder" : "Нема потсетник",
     "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
-    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "General" : "Општо",
     "Availability settings" : "Поставки за достапност",
     "CalDAV" : "CalDAV",
     "Access Nextcloud calendars from other apps and devices" : "Пристапете до Nextcloud календарите од други апликации и уреди",
     "CalDAV URL" : "CalDAV URL",
-    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
     "Appearance" : "Изглед",
     "Birthday calendar" : "Календар со родендени",
     "Tasks in calendar" : "Задачи во календарот",
@@ -225,11 +222,10 @@ OC.L10N.register(
     "Limit number of events shown in Month view" : "Ограничи го бројот на прикажани настани во преглед по месец",
     "Density in Day and Week View" : "Густина во дневен и неделен преглед",
     "Editing" : "Уредување",
+    "Default reminder" : "Стандарден потсетник",
     "Simple event editor" : "Едноставен уредувач на настани",
     "\"More details\" opens the detailed editor" : "\"Повеќе детали\" го отвора деталниот уредувач",
-    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
-    "Default reminder" : "Стандарден потсетник",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Files" : "Датотеки",
     "Appointment schedule successfully created" : "Распоред за состаноци е успешно креиран",
     "Appointment schedule successfully updated" : "Распоред за состаноци е успешно ажуриран",
     "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
@@ -289,12 +285,13 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "Успешно додадена врска до Talk разговор во локацијата.",
     "Successfully added Talk conversation link to description." : "Успешно додадена врска до Talk разговор во описот.",
     "Failed to apply Talk room." : "Не успеа примената на Talk собата.",
+    "Talk conversation for event" : "Talk разговор за настанот",
     "Error creating Talk conversation" : "Грешка при создавање на Talk разговор.",
     "Select a Talk Room" : "Изберете Talk соба",
     "Add Talk conversation" : "Додај Talk разговор",
     "Fetching Talk rooms…" : "Се преземаат Talk соби…",
     "No Talk room available" : "Нема достапни Talk соби",
-    "Create a new public conversation" : "Создај нов јавен разговор",
+    "Create public conversation" : "Создај јавен разговор",
     "Select conversation" : "Избери разговор",
     "on" : "во",
     "at" : "во",
@@ -318,7 +315,7 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "Attachment {name} already exist!" : "Прилогот {name} веќе постои!",
     "Could not upload attachment(s)" : "Неможе да се прикачи прилог",
-    "You are about to download a file. Please check the file name before opening it. Are you sure to proceed?" : "Ќе преземете датотека. Проверете го името пред да ја отворите. Дали сте сигурни дека сакате да продолжите?",
+    "You are about to navigate to {link}. Are you sure to proceed?" : "Ќе се пренасочите кон {link}. Дали сте сигурни дека сакате да продолжите?",
     "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Ќе се пренасочите кон {host}. Дали сте сигурни дека сакате да продолжите? Врска: {link}",
     "Proceed" : "Продолжи",
     "No attachments" : "Нема прилози",
@@ -379,9 +376,6 @@ OC.L10N.register(
     "Tentative" : "Пробно",
     "No attendees yet" : "Сè уште нема присутни",
     "Please add at least one attendee to use the \"Find a time\" feature." : "Додајте барем еден учесник за да ја користите функцијата \"Пронајди време\".",
-    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
-    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
-    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "Attendees" : "Присутни",
     "Remove group" : "Отстрани група",
     "Remove attendee" : "Откажи присутност",
@@ -666,7 +660,6 @@ OC.L10N.register(
     "Attachment {fileName} added!" : "Прилогот {fileName} е додаден!",
     "An error occurred during uploading file {fileName}" : "Настана грешка при прикачување на датотека {fileName}",
     "An error occurred during getting file information" : "Настана грешка при преземање на информации од датотека",
-    "Talk conversation for event" : "Talk разговор за настанот",
     "Talk conversation for proposal" : "Talk разговор за предлогот",
     "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
     "Imported {filename}" : "Импортирано {filename}",
@@ -680,6 +673,8 @@ OC.L10N.register(
     "Default attachments location" : "Стандардна локација за прилози",
     "Automatic ({detected})" : "Автоматски ({detected})",
     "Shortcut overview" : "Преглед на кратенки преку тастатура",
+    "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "Enable birthday calendar" : "Овозможи календар со родендени",
     "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
@@ -687,15 +682,17 @@ OC.L10N.register(
     "Show weekends" : "Прикажи викенди",
     "Show week numbers" : "Прикажи броеви на неделите",
     "Time increments" : "Временско зголемување",
+    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
+    "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
     "Personal availability settings" : "Параметри за лична достапност",
     "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
+    "Create a new public conversation" : "Создај нов јавен разговор",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} поканети, {confirmedCount} потврдени",
+    "Successfully appended link to talk room to location." : "Успешно е додадена врска од собата за разговор во локација.",
+    "Successfully appended link to talk room to description." : "Успешно додаден линк од собата за разговор во описот.",
+    "Error creating Talk room" : "Грешка при креирање на соба за разговор",
     "_%n more guest_::_%n more guests_" : ["%n гостин","%n други гости"],
-    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар.",
-    "View options" : "Прегледај опции ",
-    "Limit number of events shown in month view" : "Ограничи го бројот на прикажани настани во месечен преглед",
-    "Time division in day and week view" : "Поделба на време во дневен и неделен преглед",
-    "Enable simple editor" : "Овозможи едноставен уредувач"
+    "The visibility of this event in shared calendars." : "Видливост на овој настан во споделен календар."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
