@@ -41,19 +41,21 @@ OC.L10N.register(
     "Deleted" : "Suprimit",
     "Restore" : "Restaurar",
     "Delete permanently" : "Suprimir definitivament",
+    "Internal link" : "Ligam intèrn",
+    "Copy internal link" : "Copiar lo ligam intèrn",
     "Share link" : "Partejar lo ligam",
     "Copy public link" : "Copiar lo ligam public",
     "Copied code" : "Còdi copiat",
     "Could not copy code" : "Se poguèt pas copiar lo còdi",
     "Delete share link" : "Suprimir lo ligam de partatge",
     "Deleting share link …" : "Supression del ligam de partatge …",
-    "can edit" : "pòt modificar",
     "Save" : "Salvar",
     "View" : "Veire",
     "Import calendars" : "Importar de calendièrs",
     "Filename" : "Nom de fichièr",
     "Cancel" : "Anullar",
     "_Import calendar_::_Import calendars_" : ["Importar un calendièr","Importar de calendièrs"],
+    "Attachments folder" : "Dossièr de pèças-juntas",
     "Automatic" : "Automatic",
     "Navigation" : "Navegacion",
     "Views" : "Vistas",
@@ -63,9 +65,7 @@ OC.L10N.register(
     "Actions" : "Accions",
     "or" : "o",
     "General" : "Generals",
-    "Show weekends" : "Monstrar las dimenjadas",
     "Editing" : "Edicion",
-    "Keyboard shortcuts" : "Acorchis de clavièr",
     "0 minutes" : "0 minuta",
     "Update" : "Metre a jorn",
     "Location" : "Emplaçament",
@@ -184,6 +184,8 @@ OC.L10N.register(
     "Custom color" : "Color personalizada",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
     "User not found" : "Utilizaire pas trobat",
-    "Hidden" : "Amagat"
+    "Hidden" : "Amagat",
+    "can edit" : "pòt modificar",
+    "Show weekends" : "Monstrar las dimenjadas"
 },
 "nplurals=2; plural=(n > 1);");
